==> digikam-2.5.0.tar.bz2: digikam-2.5.0/core/utilities/hotplug/digikam-download.desktop.cmake <==
[Desktop Action digiKam Download]
Exec=@digikamhelperdir@/digikam-camera storage %u
Icon=digikam
Name=Download Photos with digiKam
Name[ast]=Descargar semeyes con digiKam
Name[bg]=Изтегляне на снимки с digiKam
Name[bs]=Preuzmi slike sa digiKam
Name[ca]=Descarrega les fotos amb el digiKam
Name[ca@valencia]=Descarrega les fotos amb el digiKam
Name[cs]=Stáhnout fotografie pomocí digiKamu
Name[da]=Download fotografier med digiKam
Name[de]=Fotos mit digiKam herunterladen
Name[el]=Λήψη φωτογραφιών με το digiKam
Name[en_GB]=Download Photos with digiKam
Name[es]=Descargar fotos con digiKam
Name[et]=Fotode allalaadimine digiKamiga
Name[eu]=Deskargatu argazkiak digiKam-ekin
Name[fi]=Siirrä valokuvat digiKamilla
Name[fr]=Téléchargement de photos avec digiKam
Name[gl]=Descargar fotos con digiKam
Name[hne]=डिजिकैम के साथ फोटो डाउनलोड करव
Name[hr]=Preuzmi fotografije digiKamom
Name[hu]=Fényképek letöltése digiKammal
Name[is]=Hala niður myndum með digiKam
Name[it]=Scarica foto con digiKam
Name[ja]=digiKam で写真をダウンロード
Name[km]=ទាញយក​រូបថត​ដោយ digiKam
Name[lt]=Atsisiųsti nuotraukas su digiKam
Name[lv]=Ielādēt fotogrāfijas ar digiKam
Name[nb]=Last ned fotografier med digiKam
Name[nl]=Foto's met digiKam downloaden
Name[nn]=Last ned foto med digiKam
Name[pa]=ਡਿਜਿਕੈਮ ਨਾਲ ਫੋਟੋ ਡਾਊਨਲੋਡ ਕਰੋ
Name[pl]=Pobierz zdjęcia za pomocą digiKam
Name[pt]=Obter Fotos com o digiKam
Name[pt_BR]=Transferir as fotos com o digiKam
Name[ro]=Descărcați fotografii cu digiKam
Name[ru]=Скопировать фотографии в альбом digiKam
Name[sv]=Ladda ner foton med Digikam
Name[th]=ดาวน์โหลดภาพถ่ายด้วย digiKam
Name[tr]=Fotoğrafları digiKam ile İndir
Name[uk]=Звантажити фотографії програмою digiKam
Name[x-test]=xxDownload Photos with digiKamxx
Name[zh_CN]=用 digiKam 下载照片
Name[zh_TW]=使用 digiKam 下載照片

[Desktop Entry]
Encoding=UTF-8
Actions=digiKam Download;
Type=Service
ServiceTypes=KonqPopupMenu/Plugin,media/removable_mounted,media/camera_mounted

==> digikam-2.9.0.tar.bz2: digikam-2.9.0/core/utilities/hotplug/digikam-download.desktop.cmake <==
[Desktop Action digiKam Download]
Exec=@digikamhelperdir@/digikam-camera storage %u
Icon=digikam
Name=Download Photos with digiKam
Name[ast]=Descargar semeyes con digiKam
Name[bg]=Изтегляне на снимки с digiKam
Name[bs]=Preuzmi slike sa digiKam
Name[ca]=Descarrega les fotos amb el digiKam
Name[ca@valencia]=Descarrega les fotos amb el digiKam
Name[cs]=Stáhnout fotografie pomocí digiKamu
Name[da]=Download fotografier med digiKam
Name[de]=Fotos mit digiKam herunterladen
Name[el]=Λήψη φωτογραφιών με το digiKam
Name[en_GB]=Download Photos with digiKam
Name[es]=Descargar fotos con digiKam
Name[et]=Fotode allalaadimine digiKamiga
Name[eu]=Deskargatu argazkiak digiKam-ekin
Name[fi]=Siirrä valokuvat digiKamilla
Name[fr]=Télécharger des photos avec digiKam
Name[gl]=Descargar fotos con digiKam
Name[hne]=डिजिकैम के साथ फोटो डाउनलोड करव
Name[hr]=Preuzmi fotografije digiKamom
Name[hu]=Fényképek letöltése digiKammal
Name[is]=Hala niður myndum með digiKam
Name[it]=Scarica foto con digiKam
Name[ja]=digiKam で写真をダウンロード
Name[km]=ទាញយក​រូបថត​ដោយ digiKam
Name[lt]=Atsisiųsti nuotraukas su digiKam
Name[lv]=Ielādēt fotogrāfijas ar digiKam
Name[nb]=Last ned fotografier med digiKam
Name[nl]=Foto's met digiKam downloaden
Name[nn]=Last ned foto med digiKam
Name[pa]=ਡਿਜਿਕੈਮ ਨਾਲ ਫੋਟੋ ਡਾਊਨਲੋਡ ਕਰੋ
Name[pl]=Pobierz zdjęcia za pomocą digiKam
Name[pt]=Obter Fotos com o digiKam
Name[pt_BR]=Transferir as fotos com o digiKam
Name[ro]=Descărcați fotografii cu digiKam
Name[ru]=Скопировать фотографии в альбом digiKam
Name[sv]=Ladda ner foton med Digikam
Name[th]=ดาวน์โหลดภาพถ่ายด้วย digiKam
Name[tr]=Fotoğrafları digiKam ile İndir
Name[uk]=Звантажити фотографії програмою digiKam
Name[x-test]=xxDownload Photos with digiKamxx
Name[zh_CN]=用 digiKam 下载照片
Name[zh_TW]=使用 digiKam 下載照片

[Desktop Entry]
Encoding=UTF-8
Actions=digiKam Download;
Type=Service
ServiceTypes=KonqPopupMenu/Plugin,media/removable_mounted,media/camera_mounted
